Welcome to PredFlow’s documentation! — PredFlow documentation

# Welcome to PredFlow’s documentation!

Contents:

- Documentation
  - Datasets Utilities
  - Predictive Coding Utilities
  - Supervised Autodiff Predictive Coding
  - Supervised, Fully-connected, strict-hierarchy, explicit Predictive Coding
  - Tensorflow Utilities
  - precisions_utils module
  - precision_modulated_supervised_autodiff_pc module
  - precision_modulated_supervised_explicit_pc module
- Usage
  - Train a MLP classifier on MNIST
  - Visualize the computational graph

# Indices and tables

- Index

- Module Index

- Search Page